@@ -1,5 +1,5 @@
 package i18n;
-$i18n::VERSION = '0.10';
+$i18n::VERSION = '0.11';
 
 use 5.006;
 use strict;
@@ -166,7 +166,8 @@ sub _do_loc {
     goto &$loc;
 }
 
-package i18n::string;
+package
+    i18n::string;
 
 use overload (
     '""'     => \&_stringify,
@@ -178,7 +179,8 @@ sub _stringify {
     $_[0][0]->( $_[0][1] );
 }
 
-package i18n::var;
+package
+    i18n::var;
 
 use overload (
     '""'     => \&_stringify,
@@ -198,7 +200,7 @@ i18n - Perl Internationalization Pragma
 
 =head1 VERSION
 
-This document describes version 0.10 of i18n, released October 14, 2007.
+This document describes version 0.11 of i18n, released August 10, 2016.
 
 =head1 SYNOPSIS
 
@@ -290,7 +292,7 @@ Ingy dE<ouml>t Net E<lt>INGY@cpan.orgE<gt>.
 
 =head1 COPYRIGHT
 
-Copyright 2004, 2005, 2006, 2007 by
+Copyright 2004, 2005, 2006, 2007, 2016 by
 Audrey Tang E<lt>cpan@audreyt.orgE<gt>,
 Ingy dE<ouml>t Net E<lt>INGY@cpan.orgE<gt>.
 
